@@ -9,6 +9,27 @@
 ![Release](https://github.com/stefanfreitag/azure_s3_repository_archiver/workflows/release/badge.svg)
 
 Allows to backup regularly git repositories hosted in Azure DevOps to an S3 Bucket.
+In the S3 bucket the backups are placed in a "directory" structure like
+
+```plain
+|
+|--- organization 1
+|       |
+|       |--- project 1
+|       |      |
+|       |      |--- repository 1
+|       |      |
+|       |      |--- repository 2
+|       |      |  ...
+|       |
+|       |--- project 2
+|       |
+|       |--- ...
+|
+|
+|--- organization 2
+| ...
+```
 
 ## Features
 
@@ -16,7 +37,7 @@ The S3 bucket is configured as below
 
 * enabled versioning of objects
 * enabled encryption using an S3 managed Key
-* disallowing publich access
+* disallowing public access
 * A lifecycle configuration for the archived repositories. They transistion
   through different storage classes
 
@@ -24,6 +45,7 @@ The S3 bucket is configured as below
   * Glacier after 90 days
   * Deep Archive 180 days
   * Expiry after 365 days
+* configurable notifications to SNS about uploaded/ expired objects
 
 The CodeBuild projects are configured as below
 
@@ -31,11 +53,6 @@ The CodeBuild projects are configured as below
 
   * Configurable retention period. Default is one month.
   * Encryption using customer-managed KMS key
-* Notifications to SNS about uploaded objects
-
-## Planned Features
-
-* Tagging of created AWS resources
 
 ## Prerequisites
 
@@ -47,7 +64,9 @@ The PAT needs to have "Code read" permission and stored in a SecretsManager secr
 aws secretsmanager create-secret --name repository_archiver --description "Secret for the repository archiver" --secret-string "{\"pat\":\"<your_pat>\"}"
 ```
 
-## Example (Typescript)
+## How to use
+
+### Example (Typescript)
 
 * Add the library to your dependencies, e.g to the `package.json` file
 
@@ -133,10 +152,6 @@ class Archiver(
     metaclass=jsii.JSIIMeta,
     jsii_type="azure-devops-repository-archiver.Archiver",
 ):
-    '''
-    :stability: experimental
-    '''
-
     def __init__(
         self,
         scope: _constructs_77d1e7e8.Construct,
@@ -149,11 +164,9 @@ class Archiver(
         '''
         :param scope: -
         :param id: -
-        :param backup_configurations: (experimental) Contains details on the git repositories to be backed up.
-        :param notification_events: (experimental) S3 events that will trigger a message to the SNS topic. For example "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
-        :param retention_days: (experimental) Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
-
-        :stability: experimental
+        :param backup_configurations: Contains details on the git repositories to be backed up.
+        :param notification_events: S3 events that will trigger a message to the SNS topic. For example "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
+        :param retention_days: Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__59b1d445ea6a4ea2b344c5e83eb14b7e5d57e243d55dbad607605e1e2e63c1b5)
@@ -170,9 +183,8 @@ class Archiver(
     @builtins.property
     @jsii.member(jsii_name="bucket")
     def bucket(self) -> _aws_cdk_aws_s3_ceddda9d.Bucket:
-        '''(experimental) The S3 bucket used to store the git repositories archive.
+        '''The S3 bucket used to store the git repositories archive.
 
-        :stability: experimental
         :memberof: Archiver
         :type: {s3.Bucket}
         '''
@@ -188,9 +200,8 @@ class Archiver(
     @builtins.property
     @jsii.member(jsii_name="kmsKey")
     def kms_key(self) -> _aws_cdk_aws_kms_ceddda9d.Key:
-        '''(experimental) The KMS key used to encrypt the logs and the SNS topic.
+        '''The KMS key used to encrypt the logs and the SNS topic.
 
-        :stability: experimental
         :memberof: Archiver
         :type: {kms.Key}
         '''
@@ -206,9 +217,8 @@ class Archiver(
     @builtins.property
     @jsii.member(jsii_name="logGroup")
     def log_group(self) -> _aws_cdk_aws_logs_ceddda9d.LogGroup:
-        '''(experimental) Log group used by the CodeBuild projects.
+        '''Log group used by the CodeBuild projects.
 
-        :stability: experimental
         :memberof: Archiver
         :type: {LogGroup}
         '''
@@ -224,9 +234,6 @@ class Archiver(
     @builtins.property
     @jsii.member(jsii_name="props")
     def props(self) -> "ArchiverProperties":
-        '''
-        :stability: experimental
-        '''
         return typing.cast("ArchiverProperties", jsii.get(self, "props"))
 
     @props.setter
@@ -239,9 +246,8 @@ class Archiver(
     @builtins.property
     @jsii.member(jsii_name="topic")
     def topic(self) -> _aws_cdk_aws_sns_ceddda9d.Topic:
-        '''(experimental) SNS topic to send configured bucket events to.
+        '''SNS topic to send configured bucket events to.
 
-        :stability: experimental
         :memberof: Archiver
         :type: {sns.Topic}
         '''
@@ -273,11 +279,9 @@ class ArchiverProperties:
         retention_days: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
     ) -> None:
         '''
-        :param backup_configurations: (experimental) Contains details on the git repositories to be backed up.
-        :param notification_events: (experimental) S3 events that will trigger a message to the SNS topic. For example "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
-        :param retention_days: (experimental) Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
-
-        :stability: experimental
+        :param backup_configurations: Contains details on the git repositories to be backed up.
+        :param notification_events: S3 events that will trigger a message to the SNS topic. For example "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
+        :param retention_days: Number of days to keep the Cloudwatch logs. Default: RetentionDays.ONE_MONTH
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__bfaace2f4df93a4fab67f960625a0f4057a1c4ba23833a63c0ffee999a9a724d)
@@ -294,9 +298,8 @@ class ArchiverProperties:
 
     @builtins.property
     def backup_configurations(self) -> typing.List["BackupConfiguration"]:
-        '''(experimental) Contains details on the git repositories to be backed up.
+        '''Contains details on the git repositories to be backed up.
 
-        :stability: experimental
         :memberof: ArchiverProperties
         :type: {BackupConfiguration[]}
         '''
@@ -308,12 +311,11 @@ class ArchiverProperties:
     def notification_events(
         self,
     ) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.EventType]]:
-        '''(experimental) S3 events that will trigger a message to the SNS topic.
+        '''S3 events that will trigger a message to the SNS topic.
 
         For example
         "EventType.LIFECYCLE_EXPIRATION" or "EventType.OBJECT_CREATED".
 
-        :stability: experimental
         :memberof: ArchiverProperties
         :type: {s3.EventType[]}
         '''
@@ -324,11 +326,10 @@ class ArchiverProperties:
     def retention_days(
         self,
     ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays]:
-        '''(experimental) Number of days to keep the Cloudwatch logs.
+        '''Number of days to keep the Cloudwatch logs.
 
         :default: RetentionDays.ONE_MONTH
 
-        :stability: experimental
         :memberof: ArchiverProperties
         :type: {RetentionDays}
         '''
@@ -367,12 +368,10 @@ class BackupConfiguration:
         secret_arn: builtins.str,
     ) -> None:
         '''
-        :param organization_name: (experimental) The name of the Azure DevOps organization.
-        :param project_name: (experimental) The name of the Azure DevOps project.
-        :param repository_names: (experimental) The names of the git repositories to backup.
-        :param secret_arn: (experimental) ARN of the secret containing the token for accessing the git repositories of the Azure DevOps organization.
-
-        :stability: experimental
+        :param organization_name: The name of the Azure DevOps organization.
+        :param project_name: The name of the Azure DevOps project.
+        :param repository_names: The names of the git repositories to backup.
+        :param secret_arn: ARN of the secret containing the token for accessing the git repositories of the Azure DevOps organization.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__73a3057dbc68fd09362014a7e60186c3a5a6831c5a676af4878318e4f1323881)
@@ -389,9 +388,8 @@ class BackupConfiguration:
 
     @builtins.property
     def organization_name(self) -> builtins.str:
-        '''(experimental) The name of the Azure DevOps organization.
+        '''The name of the Azure DevOps organization.
 
-        :stability: experimental
         :memberof: BackupConfiguration
         :type: {string}
         '''
@@ -401,9 +399,8 @@ class BackupConfiguration:
 
     @builtins.property
     def project_name(self) -> builtins.str:
-        '''(experimental) The name of the Azure DevOps project.
+        '''The name of the Azure DevOps project.
 
-        :stability: experimental
         :memberof: BackupConfiguration
         :type: {string}
         '''
@@ -413,9 +410,8 @@ class BackupConfiguration:
 
     @builtins.property
     def repository_names(self) -> typing.List[builtins.str]:
-        '''(experimental) The names of the git repositories to backup.
+        '''The names of the git repositories to backup.
 
-        :stability: experimental
         :memberof: BackupConfiguration
         :type: {string[]}
         '''
@@ -425,9 +421,8 @@ class BackupConfiguration:
 
     @builtins.property
     def secret_arn(self) -> builtins.str:
-        '''(experimental) ARN of the secret containing the token for accessing the git repositories of the Azure DevOps organization.
+        '''ARN of the secret containing the token for accessing the git repositories of the Azure DevOps organization.
 
-        :stability: experimental
         :memberof: BackupConfiguration
         :type: {string}
         '''
